==> OpenCL-0.03.tar.gz: OpenCL-0.03/constiv.h <==
const_iv(SUCCESS)
const_iv(DEVICE_NOT_FOUND)
const_iv(DEVICE_NOT_AVAILABLE)
const_iv(COMPILER_NOT_AVAILABLE)
const_iv(MEM_OBJECT_ALLOCATION_FAILURE)
const_iv(OUT_OF_RESOURCES)
const_iv(OUT_OF_HOST_MEMORY)
const_iv(PROFILING_INFO_NOT_AVAILABLE)
const_iv(MEM_COPY_OVERLAP)
const_iv(IMAGE_FORMAT_MISMATCH)
const_iv(IMAGE_FORMAT_NOT_SUPPORTED)
const_iv(BUILD_PROGRAM_FAILURE)
const_iv(MAP_FAILURE)
const_iv(MISALIGNED_SUB_BUFFER_OFFSET)
const_iv(EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)
const_iv(INVALID_VALUE)
const_iv(INVALID_DEVICE_TYPE)
const_iv(INVALID_PLATFORM)
const_iv(INVALID_DEVICE)
const_iv(INVALID_CONTEXT)
const_iv(INVALID_QUEUE_PROPERTIES)
const_iv(INVALID_COMMAND_QUEUE)
const_iv(INVALID_HOST_PTR)
const_iv(INVALID_MEM_OBJECT)
const_iv(INVALID_IMAGE_FORMAT_DESCRIPTOR)
const_iv(INVALID_IMAGE_SIZE)
const_iv(INVALID_SAMPLER)
const_iv(INVALID_BINARY)
const_iv(INVALID_BUILD_OPTIONS)
const_iv(INVALID_PROGRAM)
const_iv(INVALID_PROGRAM_EXECUTABLE)
const_iv(INVALID_KERNEL_NAME)
const_iv(INVALID_KERNEL_DEFINITION)
const_iv(INVALID_KERNEL)
const_iv(INVALID_ARG_INDEX)
const_iv(INVALID_ARG_VALUE)
const_iv(INVALID_ARG_SIZE)
const_iv(INVALID_KERNEL_ARGS)
const_iv(INVALID_WORK_DIMENSION)
const_iv(INVALID_WORK_GROUP_SIZE)
const_iv(INVALID_WORK_ITEM_SIZE)
const_iv(INVALID_GLOBAL_OFFSET)
const_iv(INVALID_EVENT_WAIT_LIST)
const_iv(INVALID_EVENT)
const_iv(INVALID_OPERATION)
const_iv(INVALID_GL_OBJECT)
const_iv(INVALID_BUFFER_SIZE)
const_iv(INVALID_MIP_LEVEL)
const_iv(INVALID_GLOBAL_WORK_SIZE)
const_iv(INVALID_PROPERTY)
const_iv(VERSION_1_0)
const_iv(VERSION_1_1)
const_iv(FALSE)
const_iv(TRUE)
const_iv(PLATFORM_PROFILE)
const_iv(PLATFORM_VERSION)
const_iv(PLATFORM_NAME)
const_iv(PLATFORM_VENDOR)
const_iv(PLATFORM_EXTENSIONS)
const_iv(DEVICE_TYPE_DEFAULT)
const_iv(DEVICE_TYPE_CPU)
const_iv(DEVICE_TYPE_GPU)
const_iv(DEVICE_TYPE_ACCELERATOR)
const_iv(DEVICE_TYPE_ALL)
const_iv(DEVICE_TYPE)
const_iv(DEVICE_VENDOR_ID)
const_iv(DEVICE_MAX_COMPUTE_UNITS)
const_iv(DEVICE_MAX_WORK_ITEM_DIMENSIONS)
const_iv(DEVICE_MAX_WORK_GROUP_SIZE)
const_iv(DEVICE_MAX_WORK_ITEM_SIZES)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_CHAR)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_SHORT)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_INT)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_LONG)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_FLOAT)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_DOUBLE)
const_iv(DEVICE_MAX_CLOCK_FREQUENCY)
const_iv(DEVICE_ADDRESS_BITS)
const_iv(DEVICE_MAX_READ_IMAGE_ARGS)
const_iv(DEVICE_MAX_WRITE_IMAGE_ARGS)
const_iv(DEVICE_MAX_MEM_ALLOC_SIZE)
const_iv(DEVICE_IMAGE2D_MAX_WIDTH)
const_iv(DEVICE_IMAGE2D_MAX_HEIGHT)
const_iv(DEVICE_IMAGE3D_MAX_WIDTH)
const_iv(DEVICE_IMAGE3D_MAX_HEIGHT)
const_iv(DEVICE_IMAGE3D_MAX_DEPTH)
const_iv(DEVICE_IMAGE_SUPPORT)
const_iv(DEVICE_MAX_PARAMETER_SIZE)
const_iv(DEVICE_MAX_SAMPLERS)
const_iv(DEVICE_MEM_BASE_ADDR_ALIGN)
const_iv(DEVICE_MIN_DATA_TYPE_ALIGN_SIZE)
const_iv(DEVICE_SINGLE_FP_CONFIG)
const_iv(DEVICE_GLOBAL_MEM_CACHE_TYPE)
const_iv(DEVICE_GLOBAL_MEM_CACHELINE_SIZE)
const_iv(DEVICE_GLOBAL_MEM_CACHE_SIZE)
const_iv(DEVICE_GLOBAL_MEM_SIZE)
const_iv(DEVICE_MAX_CONSTANT_BUFFER_SIZE)
const_iv(DEVICE_MAX_CONSTANT_ARGS)
const_iv(DEVICE_LOCAL_MEM_TYPE)
const_iv(DEVICE_LOCAL_MEM_SIZE)
const_iv(DEVICE_ERROR_CORRECTION_SUPPORT)
const_iv(DEVICE_PROFILING_TIMER_RESOLUTION)
const_iv(DEVICE_ENDIAN_LITTLE)
const_iv(DEVICE_AVAILABLE)
const_iv(DEVICE_COMPILER_AVAILABLE)
const_iv(DEVICE_EXECUTION_CAPABILITIES)
const_iv(DEVICE_QUEUE_PROPERTIES)
const_iv(DEVICE_NAME)
const_iv(DEVICE_VENDOR)
const_iv(DRIVER_VERSION)
const_iv(DEVICE_PROFILE)
const_iv(DEVICE_VERSION)
const_iv(DEVICE_EXTENSIONS)
const_iv(DEVICE_PLATFORM)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_HALF)
const_iv(DEVICE_HOST_UNIFIED_MEMORY)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_CHAR)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_SHORT)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_INT)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_LONG)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_FLOAT)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_DOUBLE)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_HALF)
const_iv(DEVICE_OPENCL_C_VERSION)
const_iv(FP_DENORM)
const_iv(FP_INF_NAN)
const_iv(FP_ROUND_TO_NEAREST)
const_iv(FP_ROUND_TO_ZERO)
const_iv(FP_ROUND_TO_INF)
const_iv(FP_FMA)
const_iv(FP_SOFT_FLOAT)
const_iv(NONE)
const_iv(READ_ONLY_CACHE)
const_iv(READ_WRITE_CACHE)
const_iv(LOCAL)
const_iv(GLOBAL)
const_iv(EXEC_KERNEL)
const_iv(EXEC_NATIVE_KERNEL)
const_iv(QUEUE_OUT_OF_ORDER_EXEC_MODE_ENABLE)
const_iv(QUEUE_PROFILING_ENABLE)
const_iv(CONTEXT_REFERENCE_COUNT)
const_iv(CONTEXT_DEVICES)
const_iv(CONTEXT_PROPERTIES)
const_iv(CONTEXT_NUM_DEVICES)
const_iv(CONTEXT_PLATFORM)
const_iv(QUEUE_CONTEXT)
const_iv(QUEUE_DEVICE)
const_iv(QUEUE_REFERENCE_COUNT)
const_iv(QUEUE_PROPERTIES)
const_iv(MEM_READ_WRITE)
const_iv(MEM_WRITE_ONLY)
const_iv(MEM_READ_ONLY)
const_iv(MEM_USE_HOST_PTR)
const_iv(MEM_ALLOC_HOST_PTR)
const_iv(MEM_COPY_HOST_PTR)
const_iv(R)
const_iv(A)
const_iv(RG)
const_iv(RA)
const_iv(RGB)
const_iv(RGBA)
const_iv(BGRA)
const_iv(ARGB)
const_iv(INTENSITY)
const_iv(LUMINANCE)
const_iv(Rx)
const_iv(RGx)
const_iv(RGBx)
const_iv(SNORM_INT8)
const_iv(SNORM_INT16)
const_iv(UNORM_INT8)
const_iv(UNORM_INT16)
const_iv(UNORM_SHORT_565)
const_iv(UNORM_SHORT_555)
const_iv(UNORM_INT_101010)
const_iv(SIGNED_INT8)
const_iv(SIGNED_INT16)
const_iv(SIGNED_INT32)
const_iv(UNSIGNED_INT8)
const_iv(UNSIGNED_INT16)
const_iv(UNSIGNED_INT32)
const_iv(HALF_FLOAT)
const_iv(FLOAT)
const_iv(MEM_OBJECT_BUFFER)
const_iv(MEM_OBJECT_IMAGE2D)
const_iv(MEM_OBJECT_IMAGE3D)
const_iv(MEM_TYPE)
const_iv(MEM_FLAGS)
const_iv(MEM_SIZE)
const_iv(MEM_HOST_PTR)
const_iv(MEM_MAP_COUNT)
const_iv(MEM_REFERENCE_COUNT)
const_iv(MEM_CONTEXT)
const_iv(MEM_ASSOCIATED_MEMOBJECT)
const_iv(MEM_OFFSET)
const_iv(IMAGE_FORMAT)
const_iv(IMAGE_ELEMENT_SIZE)
const_iv(IMAGE_ROW_PITCH)
const_iv(IMAGE_SLICE_PITCH)
const_iv(IMAGE_WIDTH)
const_iv(IMAGE_HEIGHT)
const_iv(IMAGE_DEPTH)
const_iv(ADDRESS_NONE)
const_iv(ADDRESS_CLAMP_TO_EDGE)
const_iv(ADDRESS_CLAMP)
const_iv(ADDRESS_REPEAT)
const_iv(ADDRESS_MIRRORED_REPEAT)
const_iv(FILTER_NEAREST)
const_iv(FILTER_LINEAR)
const_iv(SAMPLER_REFERENCE_COUNT)
const_iv(SAMPLER_CONTEXT)
const_iv(SAMPLER_NORMALIZED_COORDS)
const_iv(SAMPLER_ADDRESSING_MODE)
const_iv(SAMPLER_FILTER_MODE)
const_iv(MAP_READ)
const_iv(MAP_WRITE)
const_iv(PROGRAM_REFERENCE_COUNT)
const_iv(PROGRAM_CONTEXT)
const_iv(PROGRAM_NUM_DEVICES)
const_iv(PROGRAM_DEVICES)
const_iv(PROGRAM_SOURCE)
const_iv(PROGRAM_BINARY_SIZES)
const_iv(PROGRAM_BINARIES)
const_iv(PROGRAM_BUILD_STATUS)
const_iv(PROGRAM_BUILD_OPTIONS)
const_iv(PROGRAM_BUILD_LOG)
const_iv(BUILD_SUCCESS)
const_iv(BUILD_NONE)
const_iv(BUILD_ERROR)
const_iv(BUILD_IN_PROGRESS)
const_iv(KERNEL_FUNCTION_NAME)
const_iv(KERNEL_NUM_ARGS)
const_iv(KERNEL_REFERENCE_COUNT)
const_iv(KERNEL_CONTEXT)
const_iv(KERNEL_PROGRAM)
const_iv(KERNEL_WORK_GROUP_SIZE)
const_iv(KERNEL_COMPILE_WORK_GROUP_SIZE)
const_iv(KERNEL_LOCAL_MEM_SIZE)
const_iv(KERNEL_PREFERRED_WORK_GROUP_SIZE_MULTIPLE)
const_iv(KERNEL_PRIVATE_MEM_SIZE)
const_iv(EVENT_COMMAND_QUEUE)
const_iv(EVENT_COMMAND_TYPE)
const_iv(EVENT_REFERENCE_COUNT)
const_iv(EVENT_COMMAND_EXECUTION_STATUS)
const_iv(EVENT_CONTEXT)
const_iv(COMMAND_NDRANGE_KERNEL)
const_iv(COMMAND_TASK)
const_iv(COMMAND_NATIVE_KERNEL)
const_iv(COMMAND_READ_BUFFER)
const_iv(COMMAND_WRITE_BUFFER)
const_iv(COMMAND_COPY_BUFFER)
const_iv(COMMAND_READ_IMAGE)
const_iv(COMMAND_WRITE_IMAGE)
const_iv(COMMAND_COPY_IMAGE)
const_iv(COMMAND_COPY_IMAGE_TO_BUFFER)
const_iv(COMMAND_COPY_BUFFER_TO_IMAGE)
const_iv(COMMAND_MAP_BUFFER)
const_iv(COMMAND_MAP_IMAGE)
const_iv(COMMAND_UNMAP_MEM_OBJECT)
const_iv(COMMAND_MARKER)
const_iv(COMMAND_ACQUIRE_GL_OBJECTS)
const_iv(COMMAND_RELEASE_GL_OBJECTS)
const_iv(COMMAND_READ_BUFFER_RECT)
const_iv(COMMAND_WRITE_BUFFER_RECT)
const_iv(COMMAND_COPY_BUFFER_RECT)
const_iv(COMMAND_USER)
const_iv(COMPLETE)
const_iv(RUNNING)
const_iv(SUBMITTED)
const_iv(QUEUED)
const_iv(BUFFER_CREATE_TYPE_REGION)
const_iv(PROFILING_COMMAND_QUEUED)
const_iv(PROFILING_COMMAND_SUBMIT)
const_iv(PROFILING_COMMAND_START)
const_iv(PROFILING_COMMAND_END)

==> OpenCL-0.59.tar.gz: OpenCL-0.59/constiv.h <==
const_iv(SUCCESS)
const_iv(DEVICE_NOT_FOUND)
const_iv(DEVICE_NOT_AVAILABLE)
const_iv(COMPILER_NOT_AVAILABLE)
const_iv(MEM_OBJECT_ALLOCATION_FAILURE)
const_iv(OUT_OF_RESOURCES)
const_iv(OUT_OF_HOST_MEMORY)
const_iv(PROFILING_INFO_NOT_AVAILABLE)
const_iv(MEM_COPY_OVERLAP)
const_iv(IMAGE_FORMAT_MISMATCH)
const_iv(IMAGE_FORMAT_NOT_SUPPORTED)
const_iv(BUILD_PROGRAM_FAILURE)
const_iv(MAP_FAILURE)
const_iv(MISALIGNED_SUB_BUFFER_OFFSET)
const_iv(EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)
const_iv(INVALID_VALUE)
const_iv(INVALID_DEVICE_TYPE)
const_iv(INVALID_PLATFORM)
const_iv(INVALID_DEVICE)
const_iv(INVALID_CONTEXT)
const_iv(INVALID_QUEUE_PROPERTIES)
const_iv(INVALID_COMMAND_QUEUE)
const_iv(INVALID_HOST_PTR)
const_iv(INVALID_MEM_OBJECT)
const_iv(INVALID_IMAGE_FORMAT_DESCRIPTOR)
const_iv(INVALID_IMAGE_SIZE)
const_iv(INVALID_SAMPLER)
const_iv(INVALID_BINARY)
const_iv(INVALID_BUILD_OPTIONS)
const_iv(INVALID_PROGRAM)
const_iv(INVALID_PROGRAM_EXECUTABLE)
const_iv(INVALID_KERNEL_NAME)
const_iv(INVALID_KERNEL_DEFINITION)
const_iv(INVALID_KERNEL)
const_iv(INVALID_ARG_INDEX)
const_iv(INVALID_ARG_VALUE)
const_iv(INVALID_ARG_SIZE)
const_iv(INVALID_KERNEL_ARGS)
const_iv(INVALID_WORK_DIMENSION)
const_iv(INVALID_WORK_GROUP_SIZE)
const_iv(INVALID_WORK_ITEM_SIZE)
const_iv(INVALID_GLOBAL_OFFSET)
const_iv(INVALID_EVENT_WAIT_LIST)
const_iv(INVALID_EVENT)
const_iv(INVALID_OPERATION)
const_iv(INVALID_GL_OBJECT)
const_iv(INVALID_BUFFER_SIZE)
const_iv(INVALID_MIP_LEVEL)
const_iv(INVALID_GLOBAL_WORK_SIZE)
const_iv(INVALID_PROPERTY)
const_iv(VERSION_1_0)
const_iv(VERSION_1_1)
const_iv(FALSE)
const_iv(TRUE)
const_iv(PLATFORM_PROFILE)
const_iv(PLATFORM_VERSION)
const_iv(PLATFORM_NAME)
const_iv(PLATFORM_VENDOR)
const_iv(PLATFORM_EXTENSIONS)
const_iv(DEVICE_TYPE_DEFAULT)
const_iv(DEVICE_TYPE_CPU)
const_iv(DEVICE_TYPE_GPU)
const_iv(DEVICE_TYPE_ACCELERATOR)
const_iv(DEVICE_TYPE_ALL)
const_iv(DEVICE_TYPE)
const_iv(DEVICE_VENDOR_ID)
const_iv(DEVICE_MAX_COMPUTE_UNITS)
const_iv(DEVICE_MAX_WORK_ITEM_DIMENSIONS)
const_iv(DEVICE_MAX_WORK_GROUP_SIZE)
const_iv(DEVICE_MAX_WORK_ITEM_SIZES)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_CHAR)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_SHORT)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_INT)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_LONG)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_FLOAT)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_DOUBLE)
const_iv(DEVICE_MAX_CLOCK_FREQUENCY)
const_iv(DEVICE_ADDRESS_BITS)
const_iv(DEVICE_MAX_READ_IMAGE_ARGS)
const_iv(DEVICE_MAX_WRITE_IMAGE_ARGS)
const_iv(DEVICE_MAX_MEM_ALLOC_SIZE)
const_iv(DEVICE_IMAGE2D_MAX_WIDTH)
const_iv(DEVICE_IMAGE2D_MAX_HEIGHT)
const_iv(DEVICE_IMAGE3D_MAX_WIDTH)
const_iv(DEVICE_IMAGE3D_MAX_HEIGHT)
const_iv(DEVICE_IMAGE3D_MAX_DEPTH)
const_iv(DEVICE_IMAGE_SUPPORT)
const_iv(DEVICE_MAX_PARAMETER_SIZE)
const_iv(DEVICE_MAX_SAMPLERS)
const_iv(DEVICE_MEM_BASE_ADDR_ALIGN)
const_iv(DEVICE_MIN_DATA_TYPE_ALIGN_SIZE)
const_iv(DEVICE_SINGLE_FP_CONFIG)
const_iv(DEVICE_GLOBAL_MEM_CACHE_TYPE)
const_iv(DEVICE_GLOBAL_MEM_CACHELINE_SIZE)
const_iv(DEVICE_GLOBAL_MEM_CACHE_SIZE)
const_iv(DEVICE_GLOBAL_MEM_SIZE)
const_iv(DEVICE_MAX_CONSTANT_BUFFER_SIZE)
const_iv(DEVICE_MAX_CONSTANT_ARGS)
const_iv(DEVICE_LOCAL_MEM_TYPE)
const_iv(DEVICE_LOCAL_MEM_SIZE)
const_iv(DEVICE_ERROR_CORRECTION_SUPPORT)
const_iv(DEVICE_PROFILING_TIMER_RESOLUTION)
const_iv(DEVICE_ENDIAN_LITTLE)
const_iv(DEVICE_AVAILABLE)
const_iv(DEVICE_COMPILER_AVAILABLE)
const_iv(DEVICE_EXECUTION_CAPABILITIES)
const_iv(DEVICE_QUEUE_PROPERTIES)
const_iv(DEVICE_NAME)
const_iv(DEVICE_VENDOR)
const_iv(DRIVER_VERSION)
const_iv(DEVICE_PROFILE)
const_iv(DEVICE_VERSION)
const_iv(DEVICE_EXTENSIONS)
const_iv(DEVICE_PLATFORM)
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_HALF)
const_iv(DEVICE_HOST_UNIFIED_MEMORY)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_CHAR)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_SHORT)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_INT)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_LONG)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_FLOAT)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_DOUBLE)
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_HALF)
const_iv(DEVICE_OPENCL_C_VERSION)
const_iv(FP_DENORM)
const_iv(FP_INF_NAN)
const_iv(FP_ROUND_TO_NEAREST)
const_iv(FP_ROUND_TO_ZERO)
const_iv(FP_ROUND_TO_INF)
const_iv(FP_FMA)
const_iv(FP_SOFT_FLOAT)
const_iv(NONE)
const_iv(READ_ONLY_CACHE)
const_iv(READ_WRITE_CACHE)
const_iv(LOCAL)
const_iv(GLOBAL)
const_iv(EXEC_KERNEL)
const_iv(EXEC_NATIVE_KERNEL)
const_iv(QUEUE_OUT_OF_ORDER_EXEC_MODE_ENABLE)
const_iv(QUEUE_PROFILING_ENABLE)
const_iv(CONTEXT_REFERENCE_COUNT)
const_iv(CONTEXT_DEVICES)
const_iv(CONTEXT_PROPERTIES)
const_iv(CONTEXT_NUM_DEVICES)
const_iv(CONTEXT_PLATFORM)
const_iv(QUEUE_CONTEXT)
const_iv(QUEUE_DEVICE)
const_iv(QUEUE_REFERENCE_COUNT)
const_iv(QUEUE_PROPERTIES)
const_iv(MEM_READ_WRITE)
const_iv(MEM_WRITE_ONLY)
const_iv(MEM_READ_ONLY)
const_iv(MEM_USE_HOST_PTR)
const_iv(MEM_ALLOC_HOST_PTR)
const_iv(MEM_COPY_HOST_PTR)
const_iv(R)
const_iv(A)
const_iv(RG)
const_iv(RA)
const_iv(RGB)
const_iv(RGBA)
const_iv(BGRA)
const_iv(ARGB)
const_iv(INTENSITY)
const_iv(LUMINANCE)
const_iv(Rx)
const_iv(RGx)
const_iv(RGBx)
const_iv(SNORM_INT8)
const_iv(SNORM_INT16)
const_iv(UNORM_INT8)
const_iv(UNORM_INT16)
const_iv(UNORM_SHORT_565)
const_iv(UNORM_SHORT_555)
const_iv(UNORM_INT_101010)
const_iv(SIGNED_INT8)
const_iv(SIGNED_INT16)
const_iv(SIGNED_INT32)
const_iv(UNSIGNED_INT8)
const_iv(UNSIGNED_INT16)
const_iv(UNSIGNED_INT32)
const_iv(HALF_FLOAT)
const_iv(FLOAT)
const_iv(MEM_OBJECT_BUFFER)
const_iv(MEM_OBJECT_IMAGE2D)
const_iv(MEM_OBJECT_IMAGE3D)
const_iv(MEM_TYPE)
const_iv(MEM_FLAGS)
const_iv(MEM_SIZE)
const_iv(MEM_HOST_PTR)
const_iv(MEM_MAP_COUNT)
const_iv(MEM_REFERENCE_COUNT)
const_iv(MEM_CONTEXT)
const_iv(MEM_ASSOCIATED_MEMOBJECT)
const_iv(MEM_OFFSET)
const_iv(IMAGE_FORMAT)
const_iv(IMAGE_ELEMENT_SIZE)
const_iv(IMAGE_ROW_PITCH)
const_iv(IMAGE_SLICE_PITCH)
const_iv(IMAGE_WIDTH)
const_iv(IMAGE_HEIGHT)
const_iv(IMAGE_DEPTH)
const_iv(ADDRESS_NONE)
const_iv(ADDRESS_CLAMP_TO_EDGE)
const_iv(ADDRESS_CLAMP)
const_iv(ADDRESS_REPEAT)
const_iv(ADDRESS_MIRRORED_REPEAT)
const_iv(FILTER_NEAREST)
const_iv(FILTER_LINEAR)
const_iv(SAMPLER_REFERENCE_COUNT)
const_iv(SAMPLER_CONTEXT)
const_iv(SAMPLER_NORMALIZED_COORDS)
const_iv(SAMPLER_ADDRESSING_MODE)
const_iv(SAMPLER_FILTER_MODE)
const_iv(MAP_READ)
const_iv(MAP_WRITE)
const_iv(PROGRAM_REFERENCE_COUNT)
const_iv(PROGRAM_CONTEXT)
const_iv(PROGRAM_NUM_DEVICES)
const_iv(PROGRAM_DEVICES)
const_iv(PROGRAM_SOURCE)
const_iv(PROGRAM_BINARY_SIZES)
const_iv(PROGRAM_BINARIES)
const_iv(PROGRAM_BUILD_STATUS)
const_iv(PROGRAM_BUILD_OPTIONS)
const_iv(PROGRAM_BUILD_LOG)
const_iv(BUILD_SUCCESS)
const_iv(BUILD_NONE)
const_iv(BUILD_ERROR)
const_iv(BUILD_IN_PROGRESS)
const_iv(KERNEL_FUNCTION_NAME)
const_iv(KERNEL_NUM_ARGS)
const_iv(KERNEL_REFERENCE_COUNT)
const_iv(KERNEL_CONTEXT)
const_iv(KERNEL_PROGRAM)
const_iv(KERNEL_WORK_GROUP_SIZE)
const_iv(KERNEL_COMPILE_WORK_GROUP_SIZE)
const_iv(KERNEL_LOCAL_MEM_SIZE)
const_iv(KERNEL_PREFERRED_WORK_GROUP_SIZE_MULTIPLE)
const_iv(KERNEL_PRIVATE_MEM_SIZE)
const_iv(EVENT_COMMAND_QUEUE)
const_iv(EVENT_COMMAND_TYPE)
const_iv(EVENT_REFERENCE_COUNT)
const_iv(EVENT_COMMAND_EXECUTION_STATUS)
const_iv(EVENT_CONTEXT)
const_iv(COMMAND_NDRANGE_KERNEL)
const_iv(COMMAND_TASK)
const_iv(COMMAND_NATIVE_KERNEL)
const_iv(COMMAND_READ_BUFFER)
const_iv(COMMAND_WRITE_BUFFER)
const_iv(COMMAND_COPY_BUFFER)
const_iv(COMMAND_READ_IMAGE)
const_iv(COMMAND_WRITE_IMAGE)
const_iv(COMMAND_COPY_IMAGE)
const_iv(COMMAND_COPY_IMAGE_TO_BUFFER)
const_iv(COMMAND_COPY_BUFFER_TO_IMAGE)
const_iv(COMMAND_MAP_BUFFER)
const_iv(COMMAND_MAP_IMAGE)
const_iv(COMMAND_UNMAP_MEM_OBJECT)
const_iv(COMMAND_MARKER)
const_iv(COMMAND_ACQUIRE_GL_OBJECTS)
const_iv(COMMAND_RELEASE_GL_OBJECTS)
const_iv(COMMAND_READ_BUFFER_RECT)
const_iv(COMMAND_WRITE_BUFFER_RECT)
const_iv(COMMAND_COPY_BUFFER_RECT)
const_iv(COMMAND_USER)
const_iv(COMPLETE)
const_iv(RUNNING)
const_iv(SUBMITTED)
const_iv(QUEUED)
const_iv(BUFFER_CREATE_TYPE_REGION)
const_iv(PROFILING_COMMAND_QUEUED)
const_iv(PROFILING_COMMAND_SUBMIT)
const_iv(PROFILING_COMMAND_START)
const_iv(PROFILING_COMMAND_END)
const_iv(DEVICE_DOUBLE_FP_CONFIG)
const_iv(DEVICE_HALF_FP_CONFIG)
const_iv(PLATFORM_ICD_SUFFIX_KHR)
const_iv(PLATFORM_NOT_FOUND_KHR)
const_iv(DEVICE_COMPUTE_CAPABILITY_MAJOR_NV)
const_iv(DEVICE_COMPUTE_CAPABILITY_MINOR_NV)
const_iv(DEVICE_REGISTERS_PER_BLOCK_NV)
const_iv(DEVICE_WARP_SIZE_NV)
const_iv(DEVICE_GPU_OVERLAP_NV)
const_iv(DEVICE_KERNEL_EXEC_TIMEOUT_NV)
const_iv(DEVICE_INTEGRATED_MEMORY_NV)
const_iv(DEVICE_PROFILING_TIMER_OFFSET_AMD)
